=========
Reference
=========


Factor Tree
--------------------

The `factortree` module contains the core engine of the *Bag of Factors* package.

.. automodule:: bof.factortree
    :members:


Joint Complexity
--------------------

The `jc` module contains function to compute joint complexity between texts.

.. automodule:: bof.jc
    :members:


Common
--------------------
The `common` module contains miscellaneous classes and functions.

.. automodule:: bof.common
    :members:
